--------------------------------------------------------
--  DDL for Function ACTUALIZAR_EQUIPO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_EQUIPO" (id_equipo_in IN INTEGER, nombre_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE equipos SET
    nombre = nombre_in
  WHERE id_equipo = id_equipo_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_equipo;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_FICHAJE
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_FICHAJE" (id_fichaje_in IN INTEGER, f_baja_in IN DATE) RETURN INTEGER IS 

fecha_baja_menor_alta EXCEPTION;
f_alta_ DATE;

BEGIN

  SELECT f_alta INTO f_alta_ FROM fichajes WHERE id_fichaje = id_fichaje_in;
  
  IF (f_baja_in <= f_alta_) THEN
    RAISE fecha_baja_menor_alta;
  END IF;

  UPDATE fichajes SET
    f_baja = f_baja_in
  WHERE id_fichaje = id_fichaje_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    RETURN -3;  --id no encontrado
  WHEN fecha_baja_menor_alta THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_fichaje;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_JUGADOR
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_JUGADOR" (id_jugador_in IN INTEGER, nombre_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE jugadores SET
    nombre = nombre_in
  WHERE id_jugador = id_jugador_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_jugador;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_LIGA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_LIGA" (id_liga_in IN INTEGER, nombre_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE ligas SET
    nombre = nombre_in
  WHERE id_liga = id_liga_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_liga;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_MODALIDAD
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_MODALIDAD" (id_modalidad_in IN INTEGER, descripcion_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(descripcion_in) > 40 THEN
    RAISE too_long;
  ELSIF ((descripcion_in is NULL) OR (LENGTH(descripcion_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE modalidades SET
    descripcion = descripcion_in
  WHERE id_modalidad = id_modalidad_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_modalidad;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_PAIS
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_PAIS" (id_pais_in IN INTEGER, nombre_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE paises SET
    nombre = nombre_in
  WHERE id_pais = id_pais_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_pais;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_PARTIDO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_PARTIDO" (id_partido_in IN INTEGER, jornada_in IN DATE) RETURN INTEGER IS 

no_jornada EXCEPTION;
no_partido EXCEPTION;
BEGIN
  
  IF (id_partido_in IS NULL) THEN
    RAISE no_partido;
  ELSIF (jornada_in IS NULL) THEN
    RAISE no_jornada;
  END IF;

  UPDATE partidos SET
    jornada = jornada_in
  WHERE id_partido = id_partido_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -5;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN NO_DATA_FOUND THEN
    RETURN -4;  --id no encontrado
  WHEN no_partido THEN
    RETURN -3; --no se indica partido
  WHEN no_jornada THEN
    RETURN -2; --no se indica fecha partido
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_partido;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_TEMPORADA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_TEMPORADA" (id_temporada_in IN INTEGER, nombre_in IN VARCHAR2) RETURN INTEGER IS 

too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  UPDATE temporadas SET
    nombre = nombre_in
  WHERE id_temporada = id_temporada_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -4;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duplicado u otro error

  END actualizar_temporada;

/
--------------------------------------------------------
--  DDL for Function ACTUALIZAR_USUARIO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ACTUALIZAR_USUARIO" (id_usuario_in IN INTEGER, nombre_in VARCHAR2, localidad_in VARCHAR2, fecha_nacimiento_in DATE) RETURN INTEGER IS 

no_usuario EXCEPTION;

BEGIN
  
  IF (id_usuario_in IS NULL) THEN
    RAISE no_usuario;
  END IF;

  UPDATE usuarios SET
    nombre = nombre_in,
    localidad = localidad_in,
    fecha_nacimiento = fecha_nacimiento_in
  WHERE id_usuario = id_usuario_in;
  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha actualizado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han actualizado registros.
  END IF;

  EXCEPTION
  WHEN no_usuario THEN
    RETURN -2; --no se indica usuario
  WHEN others THEN
    RETURN -1; --duplicado o faltan datos

  END actualizar_usuario;

/
--------------------------------------------------------
--  DDL for Function ALTA_ALINEACION
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_ALINEACION" (id_partido_in IN INTEGER, id_jugador_in IN INTEGER, id_equipo_in IN INTEGER) RETURN INTEGER IS 

identificador INTEGER;
no_partido EXCEPTION;
no_jugador EXCEPTION;
no_equipo EXCEPTION;


BEGIN

  IF id_partido_in IS NULL THEN
    RAISE no_partido;
  ELSIF id_jugador_in IS NULL THEN
    RAISE no_jugador;
  ELSIF id_equipo_in IS NULL THEN
    RAISE no_equipo;
  END IF;

  identificador := seq_alineaciones.nextval;
  INSERT INTO alineaciones VALUES(identificador, id_jugador_in, id_equipo_in, id_partido_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_partido THEN
    RETURN -4;  --no se indica partido
  WHEN no_jugador THEN
    RETURN -3; --no se indica jugador
  WHEN no_equipo THEN
    RETURN -2; --no se indica equipo
  WHEN others THEN
    RETURN -1; --datos no se corresponden con partido, jugador o equipo

END alta_alineacion;

/
--------------------------------------------------------
--  DDL for Function ALTA_APUESTA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_APUESTA" (id_usuario_in IN INTEGER, id_modalidad_in IN INTEGER, id_partido_in IN INTEGER, id_jugador_in IN INTEGER, 
  goles_local_1_parte_in IN INTEGER, goles_local_2_parte_in IN INTEGER, goles_visitante_1_parte_in IN INTEGER, goles_visitante_2_parte_in IN INTEGER,
  v_e_d_in IN CHAR, importe_in IN FLOAT) RETURN INTEGER IS 

identificador INTEGER;
no_usuario EXCEPTION;
no_modalidad EXCEPTION;
no_partido EXCEPTION;
no_jugador EXCEPTION;
no_goles_1_parte EXCEPTION;
no_goles_2_parte EXCEPTION;
no_v_e_d EXCEPTION;
no_importe EXCEPTION;


BEGIN

  IF id_usuario_in IS NULL THEN
    RAISE no_usuario;
  ELSIF id_modalidad_in IS NULL THEN
    RAISE no_modalidad;
  ELSIF id_partido_in IS NULL THEN
    RAISE no_partido;
  ELSIF importe_in IS NULL THEN
    RAISE no_importe;
  ELSIF ((id_modalidad_in = 1) AND (v_e_d_in IS NULL)) THEN
    RAISE no_v_e_d;
  ELSIF ((id_modalidad_in = 2) AND (id_jugador_in IS NULL)) THEN
    RAISE no_jugador;
  ELSIF ((id_modalidad_in = 3) AND ((goles_local_1_parte_in IS NULL) OR (goles_visitante_1_parte_in IS NULL))) THEN
    RAISE no_goles_1_parte;
  ELSIF ((id_modalidad_in = 4) AND ((goles_local_2_parte_in IS NULL) OR (goles_visitante_2_parte_in IS NULL))) THEN
    RAISE no_goles_2_parte;
  END IF;

  identificador := seq_apuestas.nextval;
  INSERT INTO apuestas VALUES(identificador, id_usuario_in, id_modalidad_in, id_partido_in, id_jugador_in,
    goles_local_1_parte_in, goles_local_2_parte_in, goles_visitante_1_parte_in, goles_visitante_2_parte_in, v_e_d_in, importe_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_usuario THEN
    RETURN -9;  --no se indica usuario
  WHEN no_modalidad THEN
    RETURN -8; --no se indica modalidad
  WHEN no_partido THEN
    RETURN -7; --no se indica partido
  WHEN no_importe THEN
    RETURN -6; --no se indica importe
  WHEN no_v_e_d THEN
    RETURN -5; -- no se indica v_e_d
  WHEN no_jugador THEN
    RETURN -4; -- no se indica jugador
  WHEN no_goles_1_parte THEN
    RETURN -3; --no se indica goles 1 parte
  WHEN no_goles_2_parte THEN
    RETURN -2; --no se indica goles 2 parte
  WHEN others THEN
    RETURN -1; --datos no se corresponden con usuario, modalidad, partido, jugador

END alta_apuesta;

/
--------------------------------------------------------
--  DDL for Function ALTA_EQUIPO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_EQUIPO" (nombre_in IN VARCHAR2) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_equipos.nextval;
  INSERT INTO equipos VALUES(identificador,   nombre_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

  END alta_equipo;

/
--------------------------------------------------------
--  DDL for Function ALTA_EQUIPO_LIGA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_EQUIPO_LIGA" (id_equipo_in IN INTEGER, id_liga_in IN INTEGER, id_temporada_in IN INTEGER) RETURN INTEGER IS 

identificador INTEGER;
no_equipo EXCEPTION;
no_liga EXCEPTION;
no_temporada EXCEPTION;

BEGIN

  IF id_equipo_in IS NULL THEN
    RAISE no_equipo;
  ELSIF id_liga_in IS NULL THEN
    RAISE no_liga;
  ELSIF id_temporada_in IS NULL THEN
    RAISE no_temporada;
  END IF;

  identificador := seq_equipos_liga.nextval;
  INSERT INTO equipos_liga VALUES(identificador, id_equipo_in, id_liga_in, id_temporada_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_equipo THEN
    RETURN -4;  --no se indica equipo
  WHEN no_liga THEN
    RETURN -3; --no se indica liga
  WHEN no_temporada THEN
    RETURN -2; --no se indica temporada
  WHEN others THEN
    RETURN -1; --datos no se corresponden con equipo, liga o temporada

END alta_equipo_liga;

/
--------------------------------------------------------
--  DDL for Function ALTA_FICHAJE
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_FICHAJE" (id_equipo_in IN INTEGER, id_jugador_in IN INTEGER, f_alta_in IN DATE) RETURN INTEGER IS 

identificador INTEGER;
no_equipo EXCEPTION;
no_jugador EXCEPTION;
no_fecha_alta EXCEPTION;


BEGIN

  IF id_equipo_in IS NULL THEN
    RAISE no_equipo;
  ELSIF id_jugador_in IS NULL THEN
    RAISE no_jugador;
  ELSIF f_alta_in IS NULL THEN
    RAISE no_fecha_alta;
  END IF;

  identificador := seq_fichajes.nextval;
  INSERT INTO fichajes VALUES(identificador, f_alta_in,null, id_jugador_in, id_equipo_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_equipo THEN
    RETURN -4;  --no se indica equipo
  WHEN no_jugador THEN
    RETURN -3; --no se indica jugaor
  WHEN no_fecha_alta THEN
    RETURN -2; --no se indica fecha alta
  WHEN others THEN
    RETURN -1; --datos no se corresponden con equipo o jugador

END alta_fichaje;

/
--------------------------------------------------------
--  DDL for Function ALTA_GOL
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_GOL" (id_partido_in IN INTEGER, id_jugador_in IN INTEGER, order_in IN INTEGER) RETURN INTEGER IS 

identificador INTEGER;
no_partido EXCEPTION;
no_jugador EXCEPTION;
no_order EXCEPTION;


BEGIN

  IF id_partido_in IS NULL THEN
    RAISE no_partido;
  ELSIF id_jugador_in IS NULL THEN
    RAISE no_jugador;
  ELSIF order_in IS NULL THEN
    RAISE no_order;
  END IF;

  identificador := seq_goles.nextval;
  INSERT INTO goles VALUES(identificador, order_in, id_jugador_in, id_partido_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_partido THEN
    RETURN -4;  --no se indica partido
  WHEN no_jugador THEN
    RETURN -3; --no se indica jugador
  WHEN no_order THEN
    RETURN -2; --no se indica orden en que se produjo el gol
  WHEN others THEN
    RETURN -1; --datos no se corresponden con partido o jugador

END alta_gol;

/
--------------------------------------------------------
--  DDL for Function ALTA_JUGADOR
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_JUGADOR" (nombre_in IN VARCHAR2) RETURN INTEGER IS identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_jugadores.nextval;
  INSERT INTO jugadores VALUES(identificador,   nombre_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

END alta_jugador;

/
--------------------------------------------------------
--  DDL for Function ALTA_LIGA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_LIGA" (nombre_in IN VARCHAR2, id_pais_in IN INTEGER) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1) OR (id_pais_in IS NULL)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_ligas.nextval;
  INSERT INTO ligas VALUES(identificador, nombre_in, id_pais_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

  END alta_liga;

/
--------------------------------------------------------
--  DDL for Function ALTA_MODALIDAD
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_MODALIDAD" (nombre_in IN VARCHAR2) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_modalidades.nextval;
  INSERT INTO modalidades VALUES(identificador,   nombre_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

END alta_modalidad;

/
--------------------------------------------------------
--  DDL for Function ALTA_PAIS
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_PAIS" (nombre_in IN VARCHAR2) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_paises.nextval;
  INSERT INTO paises VALUES(identificador,   nombre_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

  END alta_pais;

/
--------------------------------------------------------
--  DDL for Function ALTA_PARTIDO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_PARTIDO" (jornada_in IN DATE, id_liga_in IN INTEGER, id_temporada_in IN INTEGER, 
    id_equipo_liga1_in IN INTEGER, id_equipo_liga2_in IN INTEGER) RETURN INTEGER IS 

identificador INTEGER;
no_jornada EXCEPTION;
no_liga EXCEPTION;
no_temporada EXCEPTION;
no_equipo_liga EXCEPTION;


BEGIN
  IF jornada_in IS NULL THEN
    RAISE no_jornada;
  ELSIF id_liga_in IS NULL THEN
    RAISE no_liga;
  ELSIF id_temporada_in IS NULL THEN
    RAISE no_temporada;
  ELSIF ((id_equipo_liga1_in IS NULL) OR (id_equipo_liga2_in IS NULL)) THEN
    RAISE no_equipo_liga;
  END IF;

  identificador := seq_partidos.nextval;
  INSERT INTO partidos VALUES(identificador,jornada_in, id_temporada_in, id_liga_in, id_equipo_liga1_in, id_equipo_liga2_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN no_jornada THEN
    RETURN -5;  --no se indica fecha jornada
  WHEN no_liga THEN
    RETURN -4; --no se indica liga
  WHEN no_temporada THEN
    RETURN -3; --no se indica temporada
  WHEN no_equipo_liga THEN
    RETURN -2; --no se indica equipo visitante y/o local
  WHEN others THEN
    RETURN -1; --datos no se corresponden con temporada, liga o equipos

END alta_partido;

/
--------------------------------------------------------
--  DDL for Function ALTA_TEMPORADA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_TEMPORADA" (nombre_in IN VARCHAR2) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF LENGTH(nombre_in) > 40 THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_temporadas.nextval;
  INSERT INTO temporadas VALUES(identificador,   nombre_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

  END alta_temporada;

/
--------------------------------------------------------
--  DDL for Function ALTA_USUARIO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."ALTA_USUARIO" (nombre_in IN VARCHAR2, localidad_in IN VARCHAR2, fecha_in DATE) RETURN INTEGER IS 

identificador INTEGER;
too_long EXCEPTION;
too_short EXCEPTION;

BEGIN

  IF ((LENGTH(nombre_in) > 40) OR (LENGTH(localidad_in) > 40)) THEN
    RAISE too_long;
  ELSIF ((nombre_in is NULL) OR (LENGTH(nombre_in) < 1) OR (localidad_in is NULL) OR(LENGTH(localidad_in) < 1) OR (fecha_in IS NULL)) THEN
    RAISE too_short;
  END IF;

  identificador := seq_usuarios.nextval;
  INSERT INTO usuarios VALUES(identificador, nombre_in, localidad_in, fecha_in);
  COMMIT;
  RETURN identificador;

  EXCEPTION
  WHEN too_long THEN
    RETURN -3;  --demasiado largo
  WHEN too_short THEN
    RETURN -2; --demasiado corto
  WHEN others THEN
    RETURN -1; --duuplicado u otro error

END alta_usuario;

/
--------------------------------------------------------
--  DDL for Function BAJA_ALINEACION
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_ALINEACION" (id_alineacion_in IN INTEGER)
RETURN INTEGER IS
no_alineacion EXCEPTION;

BEGIN
  IF (id_alineacion_in IS NULL) 
    THEN RAISE no_alineacion; 
  END IF;
  
  DELETE FROM alineaciones WHERE id_alineacion = id_alineacion_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_alineacion THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen equipos, jugadores o partidos que forman parte de ests alineacin
  
END baja_alineacion;

/
--------------------------------------------------------
--  DDL for Function BAJA_APUESTA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_APUESTA" (id_apuesta_in IN INTEGER)
RETURN INTEGER IS
no_apuesta EXCEPTION;

BEGIN
  IF (id_apuesta_in IS NULL) 
    THEN RAISE no_apuesta; 
  END IF;
  
  DELETE FROM apuestas WHERE id_apuesta = id_apuesta_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_apuesta THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado
  
END baja_apuesta;

/
--------------------------------------------------------
--  DDL for Function BAJA_EQUIPO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_EQUIPO" (id_equipo_in IN INTEGER)
RETURN INTEGER IS
no_equipo EXCEPTION;

BEGIN
  IF (id_equipo_in IS NULL) 
    THEN RAISE no_equipo; 
  END IF;
  
  DELETE FROM equipos WHERE id_equipo = id_equipo_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_equipo THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen equipos-liga, alineaciones o fichajes que forman parte de este equipo
  
END baja_equipo;

/
--------------------------------------------------------
--  DDL for Function BAJA_EQUIPO_LIGA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_EQUIPO_LIGA" (id_equipo_liga_in IN INTEGER)
RETURN INTEGER IS
no_equipo_liga EXCEPTION;

BEGIN
  IF (id_equipo_liga_in IS NULL) 
    THEN RAISE no_equipo_liga; 
  END IF;
  
  DELETE FROM equipos_liga WHERE id_equipo_liga = id_equipo_liga_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_equipo_liga THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen partidos asociados a este equipo de liga
  
END baja_equipo_liga;

/
--------------------------------------------------------
--  DDL for Function BAJA_FICHAJE
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_FICHAJE" (id_fichaje_in IN INTEGER)
RETURN INTEGER IS
no_fichaje EXCEPTION;

BEGIN
  IF (id_fichaje_in IS NULL) 
    THEN RAISE no_fichaje; 
  END IF;
  
  DELETE FROM fichajes WHERE id_fichaje = id_fichaje_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_fichaje THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen equipos o jugadores que forman parte de este fichaje
  
END baja_fichaje;

/
--------------------------------------------------------
--  DDL for Function BAJA_GOL
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_GOL" (id_gol_in IN INTEGER)
RETURN INTEGER IS
no_gol EXCEPTION;

BEGIN
  IF (id_gol_in IS NULL) 
    THEN RAISE no_gol; 
  END IF;
  
  DELETE FROM goles WHERE id_gol = id_gol_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_gol THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen partidos o jugadores que forman parte de este gol
  
END baja_gol;

/
--------------------------------------------------------
--  DDL for Function BAJA_JUGADOR
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_JUGADOR" (id_jugador_in IN INTEGER)
RETURN INTEGER IS
no_jugador EXCEPTION;

BEGIN
  IF (id_jugador_in IS NULL) 
    THEN RAISE no_jugador; 
  END IF;
  
  DELETE FROM jugadores WHERE id_jugador = id_jugador_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_jugador THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado
  
END baja_jugador;

/
--------------------------------------------------------
--  DDL for Function BAJA_LIGA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_LIGA" (id_liga_in IN INTEGER)
RETURN INTEGER IS
no_liga EXCEPTION;

BEGIN
  IF (id_liga_in IS NULL) 
    THEN RAISE no_liga; 
  END IF;
  
  DELETE FROM ligas WHERE id_liga = id_liga_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_liga THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado
  
END baja_liga;

/
--------------------------------------------------------
--  DDL for Function BAJA_MODALIDAD
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_MODALIDAD" (id_modalidad_in IN INTEGER)
RETURN INTEGER IS
no_modalidad EXCEPTION;

BEGIN
  IF (id_modalidad_in IS NULL) 
    THEN RAISE no_modalidad; 
  END IF;
  
  DELETE FROM modalidades WHERE id_modalidad = id_modalidad_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_modalidad THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado
  
END baja_modalidad;

/
--------------------------------------------------------
--  DDL for Function BAJA_PAIS
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_PAIS" (id_pais_in IN INTEGER)
RETURN INTEGER IS
no_pais EXCEPTION;

BEGIN
  IF (id_pais_in IS NULL) 
    THEN RAISE no_pais; 
  END IF;
  
  DELETE FROM paises WHERE id_pais = id_pais_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_pais THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen ligas de futbol asociadas a este pais
  
END baja_pais;

/
--------------------------------------------------------
--  DDL for Function BAJA_PARTIDO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_PARTIDO" (id_partido_in IN INTEGER)
RETURN INTEGER IS
no_partido EXCEPTION;

BEGIN
  IF (id_partido_in IS NULL) 
    THEN RAISE no_partido; 
  END IF;
  
  DELETE FROM partidos WHERE id_partido = id_partido_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_partido THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen alineaciones, goles o apuestas que forman parte de este partido
  
END baja_partido;

/
--------------------------------------------------------
--  DDL for Function BAJA_TEMPORADA
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_TEMPORADA" (id_temporada_in IN INTEGER)
RETURN INTEGER IS
no_temporada EXCEPTION;

BEGIN
  IF (id_temporada_in IS NULL) 
    THEN RAISE no_temporada; 
  END IF;
  
  DELETE FROM temporadas WHERE id_temporada = id_temporada_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_temporada THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado posiblemente existen partidos o equipos de una liga asociados a esta temporada
  
END baja_temporada;

/
--------------------------------------------------------
--  DDL for Function BAJA_USUARIO
--------------------------------------------------------

  CREATE OR REPLACE FUNCTION "OPERATIONAL"."BAJA_USUARIO" (id_usuario_in IN INTEGER)
RETURN INTEGER IS
no_usuario EXCEPTION;

BEGIN
  IF (id_usuario_in IS NULL) 
    THEN RAISE no_usuario; 
  END IF;
  
  DELETE FROM usuarios WHERE id_usuario = id_usuario_in;

  
  IF SQL%NOTFOUND THEN
    COMMIT;
    RETURN -3;  -- - no se ha borrado ningn registro.
  ELSE
    COMMIT;
    RETURN 0;  -- - se han borrado registros.
  END IF;
  
  
  EXCEPTION
  WHEN no_usuario THEN 
    RETURN -2;
  WHEN OTHERS THEN 
    RETURN -1;  --no se ha borrado
  
END baja_usuario;

/
