--------------------------------------------------------
--  DDL for Procedure OBTENER_ALINEACION
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_ALINEACION" (id_equipo_in IN INTEGER, id_partido_in IN INTEGER) IS 

no_equipo_o_partido EXCEPTION;

nombre_equipo equipos.nombre%TYPE;
jornada_partido partidos.jornada%TYPE;
temporada_partido temporadas.nombre%TYPE;
liga_partido ligas.nombre%TYPE;

CURSOR C1 IS
  SELECT j.id_jugador, j.nombre 
  FROM alineaciones a, partidos p, equipos e, jugadores j
  WHERE a.id_partido = p.id_partido AND a.id_equipo = e.id_equipo AND a.id_jugador = j.id_jugador
  AND p.id_partido = id_partido_in AND e.id_equipo = id_equipo_in
  ORDER BY j.id_jugador;

BEGIN

  IF ((id_equipo_in IS NULL) OR (id_partido_in IS NULL)) THEN
    RAISE no_equipo_o_partido;
  END IF;
  
  SELECT nombre INTO nombre_equipo FROM equipos WHERE id_equipo = id_equipo_in;
  SELECT jornada INTO jornada_partido FROM partidos WHERE id_partido = id_partido_in;
  SELECT t.nombre INTO temporada_partido FROM temporadas t, partidos p WHERE p.id_temporada = t.id_temporada AND p.id_partido = id_partido_in;
  SELECT l.nombre INTO liga_partido FROM ligas l, partidos p WHERE p.id_liga = l.id_liga AND p.id_partido = id_partido_in;
  
  DBMS_OUTPUT.put_line('Equipo: ' || TRIM(nombre_equipo) ||  
                       '   Jornada: ' || jornada_partido || 
                       '   Temporada: ' ||  TRIM(temporada_partido) ||
                       '   Liga: ' || TRIM(liga_partido));

  FOR jugadores  IN C1
   LOOP
      DBMS_OUTPUT.put_line (jugadores.id_jugador || ' ' || jugadores.nombre);
   END LOOP;

  EXCEPTION
  WHEN no_equipo_o_partido THEN
    DBMS_OUTPUT.put_line('No se especific equipo o partido');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe el equipo');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_alineacion;

/
--------------------------------------------------------
--  DDL for Procedure OBTENER_APUESTAS_USUARIO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_APUESTAS_USUARIO" (id_usuario_in IN INTEGER, id_partido_in IN INTEGER) IS 

no_usuario_o_partido EXCEPTION;

nombre_jugador jugadores.nombre%TYPE;
jornada_partido partidos.jornada%TYPE;
nombre_equipo_local equipos.nombre%TYPE;
nombre_equipo_visitante equipos.nombre%TYPE;
nombre_temporada temporadas.nombre%TYPE;
nombre_liga ligas.nombre%TYPE;
nombre_usuario usuarios.nombre%TYPE;

CURSOR C1 IS
  SELECT
    a.importe,
    CASE
      WHEN a.id_modalidad = 1 THEN m.descripcion || ': ' || v_e_d
      WHEN a.id_modalidad = 2 THEN m.descripcion  || ': ' ||  j.nombre
      WHEN a.id_modalidad = 3 THEN m.descripcion || ': ' || goles_local_1_parte || ' - ' || goles_visitante_1_parte
      WHEN a.id_modalidad = 4 THEN m.descripcion || ': ' || goles_local_2_parte || ' - ' || goles_visitante_2_parte
    END AS resultado
  FROM apuestas a, jugadores j, modalidades m
  WHERE a.id_jugador = j.id_jugador(+) AND a.id_modalidad = m.id_modalidad
  AND id_usuario = id_usuario_in AND id_partido = id_partido_in;
  
BEGIN

  IF ((id_usuario_in IS NULL) OR (id_partido_in IS NULL)) THEN
    RAISE no_usuario_o_partido;
  END IF;
  
--  SELECT nombre INTO nombre_jugador FROM jugadores WHERE id_jugador = id_jugador_in;
  SELECT jornada INTO jornada_partido FROM partidos WHERE id_partido = id_partido_in;
  SELECT e.nombre INTO nombre_equipo_local FROM partidos p,  equipos e WHERE p.id_equipo_local = e.id_equipo 
    AND p.id_partido = id_partido_in;
  SELECT e.nombre INTO nombre_equipo_visitante FROM partidos p,  equipos e WHERE p.id_equipo_visitante = e.id_equipo 
    AND p.id_partido = id_partido_in;
  SELECT t.nombre INTO nombre_temporada FROM partidos p,  temporadas t WHERE p.id_temporada = t.id_temporada 
    AND p.id_partido = id_partido_in;
  SELECT l.nombre INTO nombre_liga FROM partidos p,  ligas l WHERE p.id_liga = l.id_liga 
    AND p.id_partido = id_partido_in;
  
  DBMS_OUTPUT.put_line('Temporada: ' || TRIM(nombre_temporada) ||  
                         '   Liga: ' || TRIM(nombre_liga) ||
                         '   Jornada: ' || TRIM(jornada_partido) ||
                         '   Partido: ' || TRIM(nombre_equipo_local) || '-' || TRIM(nombre_equipo_visitante));

  FOR apuestas  IN C1
   LOOP
      DBMS_OUTPUT.put_line ('Importe apuesta: ' || apuestas.importe  || 'euros   '  ||  apuestas.resultado);
   END LOOP;

  EXCEPTION
  WHEN no_usuario_o_partido THEN
    DBMS_OUTPUT.put_line('No se especific jugador o partido');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe el usuario o partido');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_apuestas_usuario;

/
--------------------------------------------------------
--  DDL for Procedure OBTENER_EQUIPOS_LIGA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_EQUIPOS_LIGA" (id_liga_in IN INTEGER, id_temporada_in IN INTEGER) IS 

no_liga_o_temporada EXCEPTION;

nombre_temporada temporadas.nombre%TYPE;
nombre_liga ligas.nombre%TYPE;

CURSOR C1 IS
  SELECT e.nombre
  FROM equipos_liga el, equipos e
  WHERE e.id_equipo = el.id_equipo
  AND id_liga = id_liga_in AND id_temporada = id_temporada_in;

BEGIN

  IF ((id_liga_in IS NULL) OR (id_temporada_in IS NULL)) THEN
    RAISE no_liga_o_temporada;
  END IF;
  
  SELECT nombre INTO nombre_temporada FROM temporadas WHERE id_temporada = id_temporada_in;
  SELECT nombre INTO nombre_liga FROM ligas WHERE id_liga = id_liga_in;
  
  DBMS_OUTPUT.put_line('Temporada: ' || TRIM(nombre_temporada) ||  
                         '   Liga: ' || TRIM(nombre_liga));

  FOR equipos  IN C1
   LOOP
      DBMS_OUTPUT.put_line (equipos.nombre);
   END LOOP;

  EXCEPTION
  WHEN no_liga_o_temporada THEN
    DBMS_OUTPUT.put_line('No se especific liga o temporada');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe la liga o la temporada');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_equipos_liga;

/
--------------------------------------------------------
--  DDL for Procedure OBTENER_GOLES_JUGADOR_PARTIDO
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_GOLES_JUGADOR_PARTIDO" (id_jugador_in IN INTEGER, id_partido_in IN INTEGER) IS 

no_jugador_o_partido EXCEPTION;

nombre_jugador jugadores.nombre%TYPE;
jornada_partido partidos.jornada%TYPE;
nombre_equipo_local equipos.nombre%TYPE;
nombre_equipo_visitante equipos.nombre%TYPE;
nombre_temporada temporadas.nombre%TYPE;
nombre_liga ligas.nombre%TYPE;

CURSOR C1 IS
  SELECT g.orden
  FROM goles g 
  WHERE g.id_jugador = id_jugador_in AND g.id_partido = id_partido_in 
  ORDER BY orden;

BEGIN

  IF ((id_jugador_in IS NULL) OR (id_partido_in IS NULL)) THEN
    RAISE no_jugador_o_partido;
  END IF;
  
  SELECT nombre INTO nombre_jugador FROM jugadores WHERE id_jugador = id_jugador_in;
  SELECT jornada INTO jornada_partido FROM partidos WHERE id_partido = id_partido_in;
  SELECT e.nombre INTO nombre_equipo_local FROM partidos p,  equipos e WHERE p.id_equipo_local = e.id_equipo 
    AND p.id_partido = id_partido_in;
  SELECT e.nombre INTO nombre_equipo_visitante FROM partidos p,  equipos e WHERE p.id_equipo_visitante = e.id_equipo 
    AND p.id_partido = id_partido_in;
  SELECT t.nombre INTO nombre_temporada FROM partidos p,  temporadas t WHERE p.id_temporada = t.id_temporada 
    AND p.id_partido = id_partido_in;
  SELECT l.nombre INTO nombre_liga FROM partidos p,  ligas l WHERE p.id_liga = l.id_liga 
    AND p.id_partido = id_partido_in;
  
  DBMS_OUTPUT.put_line('Temporada: ' || TRIM(nombre_temporada) ||  
                         '   Liga: ' || TRIM(nombre_liga) ||
                         '   Jornada: ' || TRIM(jornada_partido) ||
                         '   Partido: ' || TRIM(nombre_equipo_local) || '-' || TRIM(nombre_equipo_visitante) ||
                         '   Jugador: ' || TRIM(nombre_jugador));

  FOR goles  IN C1
   LOOP
      DBMS_OUTPUT.put_line ('Gol marcado en orden: ' || goles.orden);
   END LOOP;

  EXCEPTION
  WHEN no_jugador_o_partido THEN
    DBMS_OUTPUT.put_line('No se especific jugador o partido');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe el jugador o partido');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_goles_jugador_partido;

/
--------------------------------------------------------
--  DDL for Procedure OBTENER_PARTIDOS_LIGA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_PARTIDOS_LIGA" (id_liga_in IN INTEGER, id_temporada_in IN INTEGER) IS 

no_liga_o_temporada EXCEPTION;

nombre_temporada temporadas.nombre%TYPE;
nombre_liga ligas.nombre%TYPE;

CURSOR C1 IS
  SELECT p.jornada, TRIM(el.nombre) as equipo_local, TRIM(ev.nombre) as equipo_visitante
  FROM partidos p, equipos el, equipos ev
  WHERE p.id_equipo_local = el.id_equipo AND p.id_equipo_visitante = ev.id_equipo
  AND id_liga = id_liga_in AND id_temporada = id_temporada_in;

BEGIN

  IF ((id_liga_in IS NULL) OR (id_temporada_in IS NULL)) THEN
    RAISE no_liga_o_temporada;
  END IF;
  
  SELECT nombre INTO nombre_temporada FROM temporadas WHERE id_temporada = id_temporada_in;
  SELECT nombre INTO nombre_liga FROM ligas WHERE id_liga = id_liga_in;
  
  DBMS_OUTPUT.put_line('Temporada: ' || TRIM(nombre_temporada) ||  
                         '   Liga: ' || TRIM(nombre_liga));

  FOR partidos  IN C1
   LOOP
      DBMS_OUTPUT.put_line(partidos.jornada || ' ' || partidos.equipo_local ||' - ' || partidos.equipo_visitante );
   END LOOP;

  EXCEPTION
  WHEN no_liga_o_temporada THEN
    DBMS_OUTPUT.put_line('No se especific liga o temporada');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe la liga o la temporada');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_partidos_liga;

/
--------------------------------------------------------
--  DDL for Procedure OBTENER_PLANTILLA
--------------------------------------------------------
set define off;

  CREATE OR REPLACE PROCEDURE "OPERATIONAL"."OBTENER_PLANTILLA" (id_equipo_in IN INTEGER) IS 

no_equipo EXCEPTION;

nombre_equipo equipos.nombre%TYPE;

CURSOR C1 IS
SELECT f.id_fichaje, f.f_alta, j.id_jugador, j.nombre 
FROM fichajes f, jugadores j
WHERE f.id_jugador = j.id_jugador
AND f_baja IS NULL
AND f.id_equipo = id_equipo_in
ORDER BY j.id_jugador;

BEGIN

  IF id_equipo_in IS NULL THEN
    RAISE no_equipo;
  END IF;
  
  SELECT nombre INTO nombre_equipo FROM equipos WHERE id_equipo = id_equipo_in;
  DBMS_OUTPUT.put_line('Equipo: ' || nombre_equipo);
-- seleccionamos los fichajes del equipo que no tienen fecha de baja
  FOR jugadores  IN C1
   LOOP
      DBMS_OUTPUT.put_line (jugadores.id_jugador || ' ' || jugadores.nombre || ' ' || jugadores.f_alta);
   END LOOP;

  EXCEPTION
  WHEN no_equipo THEN
    DBMS_OUTPUT.put_line('No se especific equipo');
  WHEN NO_DATA_FOUND THEN
    DBMS_OUTPUT.put_line('No existe el equipo');
  WHEN OTHERS THEN
    DBMS_OUTPUT.put_line('Error');
    
END obtener_plantilla;

/
